summaryrefslogtreecommitdiff
path: root/nsswitch/libwbclient
diff options
context:
space:
mode:
authorMichael Adam <obnox@samba.org>2009-01-22 13:37:11 +0100
committerMichael Adam <obnox@samba.org>2010-08-14 02:10:31 +0200
commite09a269bcc76be2101a285c0466f7fffa74366ac (patch)
treebf7ff35e45cec8a002ee86543e24d4cd8abdc72c /nsswitch/libwbclient
parenta03e2cacafacabda3fe75c784c0c360e5384339f (diff)
downloadsamba-e09a269bcc76be2101a285c0466f7fffa74366ac.tar.gz
samba-e09a269bcc76be2101a285c0466f7fffa74366ac.tar.bz2
samba-e09a269bcc76be2101a285c0466f7fffa74366ac.zip
libwbclient: unimplement wbcSetUidHwm()
Michael
Diffstat (limited to 'nsswitch/libwbclient')
-rw-r--r--nsswitch/libwbclient/wbc_idmap.c23
1 files changed, 2 insertions, 21 deletions
diff --git a/nsswitch/libwbclient/wbc_idmap.c b/nsswitch/libwbclient/wbc_idmap.c
index a125b04d7d..dc9bf36369 100644
--- a/nsswitch/libwbclient/wbc_idmap.c
+++ b/nsswitch/libwbclient/wbc_idmap.c
@@ -419,29 +419,10 @@ wbcErr wbcRemoveGidMapping(gid_t gid, const struct wbcDomainSid *sid)
return wbc_status;
}
/* Set the highwater mark for allocated uids. */
wbcErr wbcSetUidHwm(uid_t uid_hwm)
{
- struct winbindd_request request;
- struct winbindd_response response;
- wbcErr wbc_status = WBC_ERR_UNKNOWN_FAILURE;
-
- /* Initialise request */
-
- ZERO_STRUCT(request);
- ZERO_STRUCT(response);
-
- /* Make request */
-
- request.data.dual_idmapset.id = uid_hwm;
- request.data.dual_idmapset.type = _ID_TYPE_UID;
-
- wbc_status = wbcRequestResponsePriv(WINBINDD_SET_HWM,
- &request, &response);
- BAIL_ON_WBC_ERROR(wbc_status);
-
- done:
- return wbc_status;
+ return WBC_ERR_NOT_IMPLEMENTED;
}
/* Set the highwater mark for allocated gids. */
@@ -419,29 +419,10 @@ wbcErr wbcRemoveGidMapping(gid_t gid, const struct wbcDomainSid *sid)
return wbc_status;
}
-/* Set the highwater mark for allocated uids. */
+/* Set the highwater mark for allocated uids - not implemented any more */
wbcErr wbcSetUidHwm(uid_t uid_hwm)
{